@@ -27,6 +27,9 @@ LEVEL_START_TIME = "start time"
 LEVEL_END_TIME = "end time"
 UNCLASSIFIED = "unclassified"
 
+RoadUserId = str
+RoadUserType = str
+
 
 @dataclass(frozen=True)
 class EventPair:
@@ -335,6 +338,103 @@ class RoadUserAssignment:
     events: EventPair
 
 
+@dataclass
+class SelectedFlowCandidates:
+    """
+    Container for selected flow candidates.
+    """
+
+    candidates: list[FlowCandidate]
+
+    def create_assignments(
+        self, road_user_id: str, road_user_type: str
+    ) -> list[RoadUserAssignment]:
+        """
+        Create RoadUserAssignment objects from the selected flow candidates.
+
+        Args:
+            road_user_id (str): ID of the road user
+            road_user_type (str): type of the road user
+
+        Returns:
+            list[RoadUserAssignment]: list of RoadUserAssignment objects
+        """
+        return [
+            RoadUserAssignment(
+                road_user=road_user_id,
+                road_user_type=road_user_type,
+                assignment=candidate.flow,
+                events=candidate.candidate,
+            )
+            for candidate in self.candidates
+        ]
+
+
+class FlowSelection(ABC):
+    """
+    Interface for flow selection strategies.
+    """
+
+    @abstractmethod
+    def select_flows(
+        self, candidate_flows: list[FlowCandidate]
+    ) -> SelectedFlowCandidates:
+        """
+        Select flows from the given candidates based on a specific strategy.
+
+        Args:
+            candidate_flows (list[FlowCandidate]): flow candidates to select from
+
+        Returns:
+            SelectedFlowCandidates: selected flow candidates
+        """
+        raise NotImplementedError
+
+
+class MaxDurationFlowSelection(FlowSelection):
+    """
+    Flow selection strategy that selects the flow candidate with the largest duration.
+    """
+
+    def select_flows(
+        self, candidate_flows: list[FlowCandidate]
+    ) -> SelectedFlowCandidates:
+        """
+        Select the flow candidate with the largest duration.
+
+        Args:
+            candidate_flows (list[FlowCandidate]): flow candidates to select from
+
+        Returns:
+            SelectedFlowCandidates: selected flow candidate with the largest duration
+        """
+        if not candidate_flows:
+            return SelectedFlowCandidates([])
+
+        max_candidate = max(candidate_flows, key=lambda current: current.duration())
+        return SelectedFlowCandidates([max_candidate])
+
+
+class AllFlowsSelection(FlowSelection):
+    """
+    Flow selection strategy that selects all flow candidates.
+    """
+
+    def select_flows(
+        self, candidate_flows: list[FlowCandidate]
+    ) -> SelectedFlowCandidates:
+        """
+        Select all flow candidates.
+
+        Args:
+            candidate_flows (list[FlowCandidate]): flow candidates to select from
+
+        Returns:
+            SelectedFlowCandidates: all flow candidates
+        """
+        return SelectedFlowCandidates(candidate_flows)
+
+
 class Tagger(ABC):
     """
     Interface to split road user assignments into groups, e.g. by mode.
@@ -592,6 +692,18 @@ class SimpleRoadUserAssigner(RoadUserAssigner):
     Class to assign tracks to flows.
     """
 
+    def __init__(
+        self, flow_selection: FlowSelection = MaxDurationFlowSelection()
+    ) -> None:
+        """
+        Initialize the SimpleRoadUserAssigner with a flow selection strategy.
+
+        Args:
+            flow_selection (FlowSelection, optional): strategy for selecting flows.
+                Defaults to MaxDurationFlowSelection.
+        """
+        self._flow_selection = flow_selection
+
     def assign(self, events: Iterable[Event], flows: list[Flow]) -> RoadUserAssignments:
         """
         Assign each track to exactly one flow.
@@ -637,9 +749,11 @@ class SimpleRoadUserAssigner(RoadUserAssigner):
             events (Iterable[Event]): events of a road user
 
         Returns:
-            dict[int, list[Event]]: events grouped by user
+            dict[tuple[RoadUserId, RoadUserType], list[Event]]: events grouped by user
         """
-        events_by_road_user: dict[tuple[str, str], list[Event]] = defaultdict(list)
+        events_by_road_user: dict[tuple[RoadUserId, RoadUserType], list[Event]] = (
+            defaultdict(list)
+        )
         sorted_events = sorted(
             events, key=lambda _event: _event.interpolated_occurrence
         )
@@ -656,7 +770,7 @@ class SimpleRoadUserAssigner(RoadUserAssigner):
         events_by_road_user: dict[tuple[str, str], list[Event]],
     ) -> RoadUserAssignments:
         """
-        Assign each user to exactly one flow.
+        Assign each user to flows based on the flow selection strategy.
 
         Args:
             flows (dict[tuple[SectionId, SectionId], list[Flow]]): flows by start and
@@ -664,20 +778,16 @@ class SimpleRoadUserAssigner(RoadUserAssigner):
             events_by_road_user (dict[str, list[Event]]): events by road user
 
         Returns:
-            dict[str, FlowId]: assignment of flow to road user
+            RoadUserAssignments: group of RoadUserAssignment objects
         """
         assignments: list[RoadUserAssignment] = []
-        for road_user, events in events_by_road_user.items():
+        for (road_user_id, road_user_type), events in events_by_road_user.items():
             if candidate_flows := self.__create_candidates(flows, events):
-                current = self.__select_flow(candidate_flows)
-                assignments.append(
-                    RoadUserAssignment(
-                        road_user=road_user[0],
-                        road_user_type=road_user[1],
-                        assignment=current.flow,
-                        events=current.candidate,
-                    )
+                selected_flows = self._flow_selection.select_flows(candidate_flows)
+                user_assignments = selected_flows.create_assignments(
+                    road_user_id=road_user_id, road_user_type=road_user_type
                 )
+                assignments.extend(user_assignments)
         return RoadUserAssignments(assignments)
 
     def __create_candidates(
@@ -755,17 +865,6 @@ class SimpleRoadUserAssigner(RoadUserAssigner):
                         candidate_flows.append(candidate_flow)
         return candidate_flows
 
-    def __select_flow(self, candidate_flows: list[FlowCandidate]) -> FlowCandidate:
-        """
-        Select the best matching flow for the user. Best match is defined as the flow
-        with the largest distance by time.
-        Args:
-            candidate_flows (list[FlowCandidate]): flow candidates to select from
-        Returns:
-            Flow: best matching flow candidate
-        """
-        return max(candidate_flows, key=lambda current: current.duration())
-
 
 class TaggerFactory(ABC):
     """
