@@ -11,6 +11,7 @@ from OTAnalytics.application.analysis.traffic_counting import (
     LEVEL_START_TIME,
     LEVEL_TO_SECTION,
     AddSectionInformation,
+    AllFlowsSelection,
     CombinedTagger,
     Count,
     CountableAssignments,
@@ -22,11 +23,15 @@ from OTAnalytics.application.analysis.traffic_counting import (
     ExportTrafficCounting,
     FillEmptyCount,
     FilterBySectionEnterEvent,
+    FlowCandidate,
+    FlowSelection,
+    MaxDurationFlowSelection,
     ModeTagger,
     MultiTag,
     RoadUserAssigner,
     RoadUserAssignment,
     RoadUserAssignments,
+    SelectedFlowCandidates,
     SimpleRoadUserAssigner,
     SingleTag,
     Tag,
@@ -670,6 +675,145 @@ class TestCaseBuilder:
             ),
         ]
 
+    def build_max_duration_test_cases(
+        self,
+    ) -> list[tuple[list[FlowCandidate], FlowCandidate]]:
+        return [
+            self.__create_same_duration_candidates(),
+            self.__create_different_duration_candidates(),
+        ]
+
+    def build_all_flows_test_cases(
+        self,
+    ) -> list[tuple[list[FlowCandidate], list[FlowCandidate]]]:
+        return [
+            self.__create_all_flows_candidates(),
+        ]
+
+    def __create_all_flows_candidates(
+        self,
+    ) -> tuple[list[FlowCandidate], list[FlowCandidate]]:
+        first_south = create_event(self.first_track, self.south_section_id, 0)
+        first_north = create_event(self.first_track, self.north_section_id, 1)
+        first_west = create_event(self.first_track, self.west_section_id, 2)
+
+        south_north = Mock(spec=Flow)
+        north_west = Mock(spec=Flow)
+        first_candidate = FlowCandidate(
+            flow=south_north, candidate=EventPair(first_south, first_north)
+        )
+        second_candidate = FlowCandidate(
+            flow=north_west, candidate=EventPair(first_north, first_west)
+        )
+        candidates = [first_candidate, second_candidate]
+
+        return candidates, candidates
+
+    def __create_different_duration_candidates(
+        self,
+    ) -> tuple[list[FlowCandidate], FlowCandidate]:
+        first_south = create_event(self.first_track, self.south_section_id, 0)
+        first_north = create_event(self.first_track, self.north_section_id, 1)
+        first_east = create_event(self.first_track, self.east_section_id, 2)
+
+        south_east = Mock(spec=Flow)
+        south_north = Mock(spec=Flow)
+        candidates = []
+        first_candidate = FlowCandidate(
+            flow=south_east, candidate=EventPair(first_south, first_east)
+        )
+        second_candidate = FlowCandidate(
+            flow=south_north, candidate=EventPair(first_south, first_north)
+        )
+        candidates.append(first_candidate)
+        candidates.append(second_candidate)
+        expected_result = first_candidate
+
+        return candidates, expected_result
+
+    def __create_same_duration_candidates(
+        self,
+    ) -> tuple[list[FlowCandidate], FlowCandidate]:
+        first_south = create_event(self.first_track, self.south_section_id, 0)
+        first_north = create_event(self.first_track, self.north_section_id, 1)
+        first_west = create_event(self.first_track, self.west_section_id, 2)
+        first_east = create_event(self.first_track, self.east_section_id, 3)
+
+        south_north = Mock(spec=Flow)
+        north_west = Mock(spec=Flow)
+        west_east = Mock(spec=Flow)
+        first_candidate = FlowCandidate(
+            flow=south_north, candidate=EventPair(first_south, first_north)
+        )
+        second_candidate = FlowCandidate(
+            flow=north_west, candidate=EventPair(first_north, first_west)
+        )
+        third_candidate = FlowCandidate(
+            flow=west_east, candidate=EventPair(first_west, first_east)
+        )
+        candidates = [first_candidate, second_candidate, third_candidate]
+        expected_result = first_candidate
+
+        return candidates, expected_result
+
+    def build_select_flow_candidates_test_cases(
+        self,
+    ) -> list[tuple[str, str, list[FlowCandidate], list[RoadUserAssignment]]]:
+        return [
+            self.__create_single_candidate_assignment(),
+            self.__create_multiple_candidate_assignment(),
+        ]
+
+    def __create_single_candidate_assignment(
+        self,
+    ) -> tuple[str, str, list[FlowCandidate], list[RoadUserAssignment]]:
+        first_south = create_event(self.first_track, self.south_section_id, 0)
+        first_north = create_event(self.first_track, self.north_section_id, 1)
+        track_classification = "car"
+        south_north = Mock(spec=Flow)
+        south_north_pair = EventPair(first_south, first_north)
+        candidate = FlowCandidate(flow=south_north, candidate=south_north_pair)
+        expected_result = [
+            RoadUserAssignment(
+                road_user_type=track_classification,
+                road_user=self.first_track.id,
+                assignment=south_north,
+                events=south_north_pair,
+            )
+        ]
+        return self.first_track.id, track_classification, [candidate], expected_result
+
+    def __create_multiple_candidate_assignment(
+        self,
+    ) -> tuple[str, str, list[FlowCandidate], list[RoadUserAssignment]]:
+        first_south = create_event(self.first_track, self.south_section_id, 0)
+        first_north = create_event(self.first_track, self.north_section_id, 1)
+        first_east = create_event(self.first_track, self.east_section_id, 2)
+        track_classification = "car"
+        south_north = Mock(spec=Flow)
+        south_north_pair = EventPair(first_south, first_north)
+        south_east = Mock(spec=Flow)
+        south_east_pair = EventPair(first_south, first_east)
+        south_north_candidate = FlowCandidate(
+            flow=south_north, candidate=south_north_pair
+        )
+        south_east_candidate = FlowCandidate(flow=south_east, candidate=south_east_pair)
+        south_north_assignment = RoadUserAssignment(
+            road_user_type=track_classification,
+            road_user=self.first_track.id,
+            assignment=south_north,
+            events=south_north_pair,
+        )
+        south_east_assignment = RoadUserAssignment(
+            road_user_type=track_classification,
+            road_user=self.first_track.id,
+            assignment=south_east,
+            events=south_east_pair,
+        )
+        candidates = [south_north_candidate, south_east_candidate]
+        expected_result = [south_north_assignment, south_east_assignment]
+        return self.first_track.id, track_classification, candidates, expected_result
+
 
 def create_assignment_test_cases() -> (
     list[tuple[list[Event], list[Flow], RoadUserAssignments]]
@@ -710,6 +854,38 @@ class TestSimpleRoadUserAssigner:
 
         assert result == expected_result
 
+    def test_with_custom_flow_selection(
+        self, first_section_event: Event, second_section_event: Event, first_flow: Flow
+    ) -> None:
+        events = [first_section_event, second_section_event]
+        flows = [first_flow]
+        flow_selection = self._create_flow_selection()
+        target = self._create_target(flow_selection)
+
+        target.assign(events, flows)
+
+        flow_selection.select_flows.assert_called_once_with(
+            [
+                FlowCandidate(
+                    first_flow, EventPair(first_section_event, second_section_event)
+                )
+            ]
+        )
+
+    def _create_flow_selection(self) -> Mock:
+        flow_selection = Mock(spec=FlowSelection)
+        selected_candidates = SelectedFlowCandidates([])
+        flow_selection.select_flows.return_value = selected_candidates
+        return flow_selection
+
+    def _create_target(self, flow_selection: Mock) -> RoadUserAssigner:
+        return SimpleRoadUserAssigner(flow_selection=flow_selection)
+
+    def test_default_flow_selection(self) -> None:
+        target = SimpleRoadUserAssigner()
+
+        assert isinstance(target._flow_selection, MaxDurationFlowSelection)
+
 
 def create_counting_test_cases() -> list[tuple]:
     return TestCaseBuilder().create_counting_test_cases()
@@ -785,6 +961,89 @@ class TestCombinedTagger:
         assert group_name == MultiTag(frozenset([first_id, second_id]))
 
 
+class TestMaxDurationFlowSelection:
+    def test_select_flows_with_empty_list(self) -> None:
+        target = self._create_target()
+        result = target.select_flows([])
+
+        assert isinstance(result, SelectedFlowCandidates)
+        assert result.candidates == []
+
+    def _create_target(self) -> MaxDurationFlowSelection:
+        return MaxDurationFlowSelection()
+
+    @pytest.mark.parametrize(
+        "candidates, expected_result", TestCaseBuilder().build_max_duration_test_cases()
+    )
+    def test_select_flows(
+        self,
+        candidates: list[FlowCandidate],
+        expected_result: FlowCandidate,
+    ) -> None:
+        target = self._create_target()
+
+        result = target.select_flows(candidates)
+
+        assert isinstance(result, SelectedFlowCandidates)
+        assert len(result.candidates) == 1
+        assert result.candidates[0] == expected_result
+
+
+class TestAllFlowsSelection:
+    def test_select_flows_with_empty_list(self) -> None:
+        target = self._create_target()
+        result = target.select_flows([])
+
+        assert isinstance(result, SelectedFlowCandidates)
+        assert result.candidates == []
+
+    def _create_target(self) -> AllFlowsSelection:
+        return AllFlowsSelection()
+
+    @pytest.mark.parametrize(
+        "candidates, expected_result", TestCaseBuilder().build_all_flows_test_cases()
+    )
+    def test_select_flows(
+        self,
+        candidates: list[FlowCandidate],
+        expected_result: list[FlowCandidate],
+    ) -> None:
+        target = self._create_target()
+
+        result = target.select_flows(candidates)
+
+        assert isinstance(result, SelectedFlowCandidates)
+        assert len(result.candidates) == len(expected_result)
+        assert result.candidates == expected_result
+
+
+class TestSelectedFlowCandidates:
+    def test_create_assignments_with_empty_list(self) -> None:
+        """Test that creating assignments from an empty list returns an empty list."""
+        selected = SelectedFlowCandidates([])
+        result = selected.create_assignments("user1", "car")
+
+        assert isinstance(result, list)
+        assert len(result) == 0
+
+    @pytest.mark.parametrize(
+        "road_user_id, road_user_type, candidates, expected_result",
+        TestCaseBuilder().build_select_flow_candidates_test_cases(),
+    )
+    def test_create_assignments(
+        self,
+        road_user_id: str,
+        road_user_type: str,
+        candidates: list[FlowCandidate],
+        expected_result: list[RoadUserAssignment],
+    ) -> None:
+        target = SelectedFlowCandidates(candidates)
+
+        result = target.create_assignments(road_user_id, road_user_type)
+
+        assert result == expected_result
+
+
 class TestCountableAssignments:
     @pytest.mark.parametrize(
         "assignments, flows, expected_result", create_counting_test_cases()
